@@ -5,12 +5,18 @@
 #pragma once
 
 #include <QObject>
-#include <akonadi_version.h>
 #include <Akonadi/AgentFilterProxyModel>
 #include <Akonadi/CollectionFilterProxyModel>
 #include <Akonadi/ETMViewStateSaver>
 #include <Akonadi/EntityRightsFilterModel>
+
+#include <QObject>
+#include <akonadi-calendar_version.h>
+#if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
+#include <Akonadi/IncidenceChanger>
+#else
 #include <Akonadi/Calendar/IncidenceChanger>
+#endif
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 #include <KConfigWatcher>
@@ -127,4 +133,4 @@ private:
     KConfigWatcher::Ptr m_colorWatcher;
 };
 
-Q_DECLARE_METATYPE(Akonadi::ETMCalendar::Ptr);
+Q_DECLARE_METATYPE(Akonadi::ETMCalendar::Ptr)
